==> soupsavvy-0.2.2.tar.gz: soupsavvy-0.2.2/README.md <==
![SoupSavvy](https://github.com/sewcio543/soupsavvy/blob/main/resources/logo.png?raw=true)
========

## Powerful and flexible engine for BeautifulSoup

[![PyPI](https://img.shields.io/pypi/v/soupsavvy?color=orange)](https://pypi.org/project/soupsavvy/) [![Python Versions](https://img.shields.io/pypi/pyversions/soupsavvy)](https://www.python.org/) [![Codecov](https://codecov.io/gh/sewcio543/soupsavvy/graph/badge.svg?token=RZ51VS3QLB)](https://codecov.io/gh/sewcio543/soupsavvy) [![Docs link](https://img.shields.io/badge/docs-read-blue)](https://soupsavvy.readthedocs.io)

## Table of Contents

- [About](#about)
- [Key features](#key-features)
- [Instalation](#installation)
- [Documentation](#documentation)
- [Demos](#demos)
- [Contributing](#contributing)
- [License](#license)
- [Acknowledgements](#acknowledgements)

## About

**soupsavvy** is flexible search engine for `BeautifulSoup`, designed to provide more powerful capabilities, making more complex searches simple and web scraping tasks more efficient and manageable.

## Key Features

`soupsavvy` introduces the concept of a `Selector`, a declarative search procedure designed with simple and readable syntax. It encapsulates search logic, making it reusable across different scenarios. The package offers various types of selectors that can be easily combined to perform more complex searches.

## Installation

`soupsavvy` is published on PyPi and can be installed via pip:

```bash
pip install soupsavvy
```

## Documentation

Full documentation can be found at **[documentation](https://soupsavvy.readthedocs.io)**.

## Demos

For more information about the package, its concepts and usage, read `Demos` section of the **[documentation](https://soupsavvy.readthedocs.io)**. It's step by step guide to the most important features of the package.

## Contributing

If you'd like to contribute to soupsavvy, feel free to check out the [GitHub repository](https://github.com/sewcio543/soupsavvy) and submit pull requests into one of development branches. Any feedback, bug reports, or feature requests are welcome! In case of any doubts, follow [Contribution Guidelines](https://github.com/sewcio543/soupsavvy/blob/main/CONTRIBUTING.md)

## License

[![MIT License](https://img.shields.io/badge/license-MIT-green?style=plastic)](https://choosealicense.com/licenses/mit/)
`soupsavvy` is licensed under the [MIT License](https://opensource.org/licenses/MIT), allowing for both personal and commercial use. See the `LICENSE` file for more information.

## Acknowledgements

`soupsavvy` is built upon the foundation of excellent `BeautifulSoup`. We extend our gratitude to the developers of this projects for their invaluable contributions to the Python community and making our life a lot easier!

-----------------

**Let's soap this soup!**
**Happy scraping!** ✨

==> soupsavvy-0.3.0.tar.gz: soupsavvy-0.3.0/README.md <==
![soupsavvy](https://github.com/sewcio543/soupsavvy/blob/main/resources/logo.png?raw=true)
========

## Powerful and flexible engine for BeautifulSoup

[![PyPI](https://img.shields.io/pypi/v/soupsavvy?color=orange)](https://pypi.org/project/soupsavvy/) [![Python Versions](https://img.shields.io/pypi/pyversions/soupsavvy)](https://www.python.org/) [![Codecov](https://codecov.io/gh/sewcio543/soupsavvy/graph/badge.svg?token=RZ51VS3QLB)](https://codecov.io/gh/sewcio543/soupsavvy) [![Docs link](https://img.shields.io/badge/docs-read-blue)](https://soupsavvy.readthedocs.io)

## Table of Contents

- [About](#about)
- [Key features](#key-features)
- [Installation](#installation)
- [Documentation](#documentation)
- [Demos](#demos)
- [Contributing](#contributing)
- [License](#license)
- [Acknowledgements](#acknowledgements)

## About

**soupsavvy** is flexible search engine for [`BeautifulSoup`](https://pypi.org/project/beautifulsoup4/), designed to provide more powerful capabilities, making more complex searches simple and web scraping tasks more efficient and manageable.

## Key Features

`soupsavvy` introduces the concept of `Selector`, a declarative search procedure designed with simple and readable syntax. It encapsulates search logic, making it reusable across different scenarios. The package offers various types of selectors that can be easily combined to perform more complex searches.

## Installation

`soupsavvy` is published on PyPi and can be installed via pip:

```bash
pip install soupsavvy
```

## Documentation

Full documentation can be found at **[documentation](https://soupsavvy.readthedocs.io)**.

## Demos

For more information about the package, its concepts and usage, read `Demos` section of the **[documentation](https://soupsavvy.readthedocs.io)**. It's step by step guide to the most important features of the package.

## Contributing

If you'd like to contribute to soupsavvy, feel free to check out the [GitHub repository](https://github.com/sewcio543/soupsavvy) and submit pull requests into one of development branches. Any feedback, bug reports, or feature requests are welcome! In case of any doubts, follow [Contribution Guidelines](https://github.com/sewcio543/soupsavvy/blob/main/CONTRIBUTING.md)

## License

`soupsavvy` is licensed under ![MIT License](https://img.shields.io/badge/license-MIT-green?style=plastic), allowing for both personal and commercial use. See the `LICENSE` file for more information.

## Acknowledgements

`soupsavvy` is built upon the foundation of excellent `BeautifulSoup`. We extend our gratitude to the developers of this projects for their invaluable contributions to the Python community and making our life a lot easier!

-----------------

**Happy scraping!** ✨
